# Theta Data Python API

The [Theta Data](https://thetadata.net) Python API provides low latency options data that may be used for
market research or algorithmic trading applications.

Please see this repository's [documentation](https://thetadata-api.github.io/PythonAPI) for more details.

## Installation

Java 11 or higher is required

`pip install thetadata`

A Theta Data account is required to access data. After obtaining an account, please
see our [official installation instructions](https://thetadata-api.github.io/PythonAPI/tutorials/#installation)
to get started.

## Contributing

We welcome all feedback, whether it comes in the form of Github issues, pull requests, or pings in our Discord!
